##  Template Components
The table below lists available template components and explains when to use each.
Component | Usage
---|---
Text |  This component provides an input field for text in Markdown format and supports adding links, tables, and diagrams. It's the base component for documenting key decision details, such as the background, options, decision, and comments. With diagrams, you can compare target planning options and visualize dependencies, risks, or timelines directly within decisions. For more information, see [Diagrams in Architecture Decisions](https://help.sap.com/docs/leanix/ea/architecture-decisions?locale=en-US&state=PRODUCTION&version=CLOUD#loio2758b7ff7a441014bb6ac52c04964f3b__section_tsv_xsy_tgc).
Fact sheet | This component represents an architectural element associated with a decision. Listing affected fact sheets helps track the decision's impact across various areas of the IT landscape.
User |  This component identifies workspace users involved in a decision. Use it to mention decision owners, approvers, or meeting participants. It ensures accountability and transparency by clearly identifying individuals in the decision-making process.
  * You can only mention active workspace users.
  * Users cannot subscribe to decisions.
  * Users don’t receive notifications when mentioned in a decision.


Date picker | This component allows selecting specific dates crucial for tracking and managing various timelines associated with a decision. Use it to set deadlines, validity periods, review schedules, and approval dates to ensure timely follow-ups and adherence to expected timelines.


